@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: mgd77convert.c 10344 2016-03-07 01:35:42Z pwessel $
+ *	$Id: mgd77convert.c 10374 2017-01-16 20:53:19Z pwessel $
  *
- *    Copyright (c) 2005-2016 by P. Wessel
+ *    Copyright (c) 2005-2017 by P. Wessel
  *    See README file for copying and redistribution conditions.
  *--------------------------------------------------------------------*/
 /*
@@ -29,8 +29,8 @@ int main (int argc, char **argv)
 		
 	GMT_LONG error = FALSE, force = FALSE, high_resolution = FALSE, original = FALSE;
 	
-	char file[BUFSIZ], **list = NULL, *fcode = "actm";
-	char *format_name[MGD77_N_FORMATS] = {"MGD77 ASCII", "MGD77+ netCDF", "ASCII table", "MGD77T ASCII"};
+	char file[BUFSIZ], **list = NULL, *fcode = "cmat";
+	char *format_name[MGD77_N_FORMATS] = {"MGD77+ netCDF", "MGD77T ASCII", "MGD77 ASCII", "ASCII table"};
 
 	struct MGD77_CONTROL M;
 	struct MGD77_DATASET *D = NULL;
