@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: mgd77header.c 10362 2016-08-20 00:20:25Z remko $
+ *	$Id: mgd77header.c 10374 2017-01-16 20:53:19Z pwessel $
  *
- *    Copyright (c) 2004-2016 by P. Wessel and Michael Chandler
+ *    Copyright (c) 2004-2017 by P. Wessel and Michael Chandler
  *    See README file for copying and redistribution conditions.
  *--------------------------------------------------------------------*/
 /*
@@ -34,16 +34,16 @@ EXTERN_MSC int MGD77_Read_Data_asc (char *file, struct MGD77_CONTROL *F, struct
 EXTERN_MSC int MGD77_Read_Data_cdf (char *file, struct MGD77_CONTROL *F, struct MGD77_DATASET *S);
 EXTERN_MSC int MGD77_Read_Header_Record_cdf (char *file, struct MGD77_CONTROL *F, struct MGD77_HEADER *H);
 EXTERN_MSC int MGD77_Decode_Header_m77t (struct MGD77_HEADER_PARAMS *P, char *record);
+EXTERN_MSC int MGD77_Write_Header_Record_m77t (char *file, struct MGD77_CONTROL *F, struct MGD77_HEADER *H);
 
 int main (int argc, char **argv)
 {
-	GMT_LONG i, id, rec, argno, col_listing = 3, length, id_col, t_col, x_col, y_col, saved_range, use;
-	GMT_LONG header_flag = 0, n_paths, counter[MGD77_MAX_COLS], agency_listing = 1, quad_no, n_quad;
+	GMT_LONG i, id, rec, argno, length, id_col, t_col, x_col, y_col, saved_range, use;
+	GMT_LONG header_flag = 0, n_paths, counter[MGD77_MAX_COLS], quad_no, n_quad;
 
-	GMT_LONG error = FALSE, greenwich = FALSE, quick_summary = FALSE, dump_raw_header = FALSE;
-	GMT_LONG first = TRUE, col_summary = FALSE, read_file, dump_formatted_header = FALSE;
-	GMT_LONG quick_agencies = FALSE, dump_e77_header = FALSE, dump_hist_header = FALSE;
-	GMT_LONG quad[4] = {FALSE, FALSE, FALSE, FALSE}, b_col, m_col, f_col;
+	GMT_LONG error = FALSE, greenwich = FALSE, dump_raw_header = FALSE;
+	GMT_LONG dump_formatted_header = FALSE, dump_m77t_header = FALSE;
+	GMT_LONG quad[4] = {FALSE, FALSE, FALSE, FALSE}, b_col, twt_col, g_col, m_col, f_col, mt1_col, mt2_col;
 	int tendeg[36][18], tenx, teny, nten = 0, tquad;
 
 	double this_dist, this_lon, this_lat, last_lon, last_lat, dx, dy, dlon, ds, lon_w;
@@ -82,23 +82,6 @@ int main (int argc, char **argv)
 				error += GMT_parse_common_options (argv[i], NULL, NULL, NULL, NULL);
 				break;
 
-			case 'C':	/* Get the short list [Default] */
-				switch (argv[i][2]) {
-					case 'm':
-					case 'M':
-						col_listing = 1;
-						break;
-					case 'e':
-					case 'E':
-						col_listing = 2;
-						break;
-					default:
-						col_listing = 3;
-						break;
-				}
-				col_summary = TRUE;
-				break;
-
 			case 'H':
 				strcpy (hinfile, &argv[i][2]);
 				infile = fopen (hinfile, "r");
@@ -114,57 +97,16 @@ int main (int argc, char **argv)
 					header_flag = MGD77_Select_Header_Item (&M, &argv[i][3]);
 					if (header_flag < 0) error++;
 				}
-				else if (argv[i][2] == 'r') {
+				else if (argv[i][2] == 'r')
 					dump_raw_header = TRUE;
-				}
-				else if (argv[i][2] == 'e') {
-					dump_e77_header = TRUE;
-				}
-				else if (argv[i][2] == 'h') {
-					dump_hist_header = TRUE;
-				}
+				else if (argv[i][2] == 't')
+					dump_m77t_header = TRUE;
 				else {
-					fprintf (stderr, "%s: Option -M Bad modifier (%c). Use -Mf|r|e|h!\n", GMT_program, argv[i][2]);
+					fprintf (stderr, "%s: Option -M Bad modifier (%c). Use -Mf|r!\n", GMT_program, argv[i][2]);
 					exit (EXIT_FAILURE);
 				}
 				break;
 
-			case 'I':
-				MGD77_Process_Ignore (argv[i][1], &argv[i][2]);
-				break;
-
-			case 'E':	/* Get the short list [Default] */
-				switch (argv[i][2]) {
-					case 'm':
-					case 'M':
-						col_listing = 1;
-						break;
-					case 'e':
-					case 'E':
-						col_listing = 2;
-						break;
-					default:
-						col_listing = 3;
-						break;
-				}
-				quick_summary = TRUE;
-				break;
-
-			case 'L':	/* Get the list of institutions and vessels  */
-				switch (argv[i][2]) {
-					case 'a':
-						agency_listing = 1;
-						break;
-					case 'v':
-						agency_listing = 2;
-						break;
-					default:
-						col_listing = 1;
-						break;
-				}
-				quick_agencies = TRUE;
-				break;
-
 			default:		/* Options not recognized */
 				error = TRUE;
 				break;
@@ -177,53 +119,28 @@ int main (int argc, char **argv)
 
 	if (GMT_give_synopsis_and_exit || argc == 1 || header_flag == 1) {	/* Display usage */
 		fprintf (stderr, "mgd77header %s - Extract information about MGD77 files\n\n", MGD77_VERSION);
-		fprintf (stderr, "usage: mgd77header <cruise(s)> [-C[m|e]] [-E[m|e]] [-H<file> [-I<code>] [-Mf[<item>]|r|e|h] [-L[v]] [-V]\n\n");
+		fprintf (stderr, "usage: mgd77header <cruise(s)> [-H<file> [-Mf[<item>]|r|t] [-V]\n\n");
 
 		if (GMT_give_synopsis_and_exit) exit (EXIT_FAILURE);
 
 		MGD77_Cruise_Explain ();
-		fprintf (stderr, "\tOPTIONS:\n\n");
-		fprintf (stderr, "\t-C List abbreviations of all columns present for each cruise\n");
-		fprintf (stderr, "\t   Append m for listing just the MGD77 columns present\n");
-		fprintf (stderr, "\t   Append e for listing just any extra columns present\n");
-		fprintf (stderr, "\t-E Give the information summary of each cruise's geographical/temporal extent\n");
-		fprintf (stderr, "\t   Append m for counting just the number of non-NaN values for each MGD77 field\n");
-		fprintf (stderr, "\t   Append e for counting just the of non-NaN values for each extra field\n");
+		fprintf (stderr, "\n\tOPTIONS:\n\n");
 		fprintf (stderr, "\t-H Read and assign header values from a file. Each input file row gives an exact\n");
 		fprintf (stderr, "\t   header_field_name, space or tab, and header value. Values are read according to\n");
 		fprintf (stderr, "\t   NGDC's MGD77 header format specification.\n\t\te.g.,\n\t\tSource_Institution Univ. of Hawaii\n");
 		fprintf (stderr, "\t\tPort_of_Arrival Honolulu, HAWAII\n\t\t...\n	   See mgd77info -Mf output for recognized header field names.\n");
-		fprintf (stderr, "\t-M Print header items (and MGD77+ history).  Append type of presentation:\n");
+		fprintf (stderr, "\t-M Print header items.  Append type of presentation:\n");
 		fprintf (stderr, "\t     f: Print header items individually, one per line.  Append name of a particular\n");
 		fprintf (stderr, "\t        item (e.g., Port_of_Departure), all [Default], or - to see a list of items.\n");
 		fprintf (stderr, "\t        You can also use the number of the item.\n");
-		fprintf (stderr, "\t     r: Display raw original MGD77 header records.\n");
-		fprintf (stderr, "\t     e: Display the MGD77+ file's E77 status.\n");
-		fprintf (stderr, "\t     h: Display the MGD77+ file's history.\n");
+		fprintf (stderr, "\t     r: Display raw original MGD77 header records [Default].\n");
+		fprintf (stderr, "\t     t: Display raw original M77T header records.\n");
 		if (header_flag == 1) MGD77_List_Header_Items (&M);
-		fprintf (stderr, "\t-I Ignore certain data file formats from consideration. Append combination of act to ignore\n");
-		fprintf (stderr, "\t   (a) MGD77 ASCII, (c) MGD77+ netCDF, (m) MGD77T ASCII, or (t) plain table files. [Default ignores none]\n");
-		fprintf (stderr, "\t-L Just list all the institutions and their 2-character GEODAS codes.  Append v to also\n");
-		fprintf (stderr, "\t   display the vessels and their 4-character codes for each institution\n");
 		fprintf (stderr, "\t-V verbose, report progress\n");
 		exit (EXIT_FAILURE);
 	}
 
-	if (dump_raw_header + dump_e77_header + dump_hist_header + quick_summary + col_summary + dump_formatted_header + quick_agencies == 0) {
-		fprintf(stderr, "%s: ERROR: Specify one of -C, -E, -L, or -M\n", GMT_program);
-		exit (EXIT_FAILURE);
-	}
-
-	if (quick_agencies) {	/* Just display the list and exit */
-		(agency_listing == 2) ? printf ("CODE\tINSTITUTION/VESSEL\n") : printf ("CODE\tINSTITUTION\n");
-		for (id = i = 0; id < MGD77_N_AGENCIES; id++) {
-			printf ("%s = %s\n", MGD77_agency[id].code, MGD77_agency[id].name);
-			for (; agency_listing == 2 && i < MGD77_N_VESSELS && MGD77_vessel[i].agent == id; i++) {
-				printf ("%s\t-> %s\n", MGD77_vessel[i].code, MGD77_vessel[i].name);
-			}
-		}
-		exit (EXIT_SUCCESS);
-	}
+	if (!dump_formatted_header &&!dump_m77t_header) dump_raw_header = TRUE;
 
 	n_paths = MGD77_Path_Expand (&M, argv, argc, &list);	/* Get list of requested IDs */
 
@@ -232,17 +149,9 @@ int main (int argc, char **argv)
 		exit (EXIT_FAILURE);
 	}
 
-	read_file = (quick_summary || dump_raw_header || dump_formatted_header);
-
 	saved_range = GMT_io.geo.range;	/* We may have to reset thisso keep a copy */
 	GMT_io.out_col_type[0] = GMT_IS_LON;	GMT_io.out_col_type[1] = GMT_IS_LAT;
 	GMT_io.out_col_type[2] = M.time_format;
-	if (quick_summary) {
-		sprintf (buffer, "#Cruise %sID      %sWest    %sEast    %sSouth   %sNorth   %sStartTime%s%sEndTime%s%s%sDist%snRec",
-		gmtdefs.field_delimiter, gmtdefs.field_delimiter, gmtdefs.field_delimiter, gmtdefs.field_delimiter, gmtdefs.field_delimiter, gmtdefs.field_delimiter,
-		gmtdefs.field_delimiter, gmtdefs.field_delimiter, gmtdefs.field_delimiter, gmtdefs.field_delimiter, gmtdefs.field_delimiter, gmtdefs.field_delimiter);
-		GMT_fputs (buffer, GMT_stdout);
-	}
 
 	use = (M.original || M.format != MGD77_FORMAT_CDF) ? MGD77_ORIG : MGD77_REVISED;
 
@@ -254,21 +163,21 @@ int main (int argc, char **argv)
 
 		D = MGD77_Create_Dataset ();
 
-		if (read_file && MGD77_Read_File_nohdr (list[argno], &M, D)) {
+		if (MGD77_Read_File_nohdr (list[argno], &M, D)) {
 			fprintf (stderr, "%s: Error reading data for cruise %s\n", GMT_program, list[argno]);
 			exit (EXIT_FAILURE);
 		}
-		if (!read_file && MGD77_Read_Header_Record_nohdr (list[argno], &M, &D->H)) {
-			fprintf (stderr, "%s: Error reading header sequence for cruise %s\n", GMT_program, list[argno]);
-			exit (EXIT_FAILURE);
-		}
 
 		t_col = MGD77_Get_Column ("time", &M);
 		x_col = MGD77_Get_Column ("lon", &M);
 		y_col = MGD77_Get_Column ("lat", &M);
 		b_col = MGD77_Get_Column ("depth", &M);
+		twt_col = MGD77_Get_Column ("twt", &M);
 		m_col = MGD77_Get_Column ("mag", &M);
+		mt1_col = MGD77_Get_Column ("mtf1", &M);
+		mt2_col = MGD77_Get_Column ("mtf2", &M);
 		f_col = MGD77_Get_Column ("faa", &M);
+		g_col = MGD77_Get_Column ("gobs", &M);
 		id_col = MGD77_Get_Column ("id", &M);
 
 		GMT_make_dnan (tmin);
@@ -338,10 +247,12 @@ int main (int argc, char **argv)
             else tenx = floor (this_lon/10)+18;
 			if (!tendeg[tenx][teny]) {
 				tendeg[tenx][teny] = 1;
+#if 0
                 if (this_lon > 180)
-                fprintf (stderr,"lon: %.5f lat: %.5f\ttendeg[%d][%d] = %d\n",this_lon-360,this_lat,tenx,teny,tendeg[tenx][teny]);
+                	fprintf (stderr,"lon: %.5f lat: %.5f\ttendeg[%d][%d] = %d\n",this_lon-360,this_lat,tenx,teny,tendeg[tenx][teny]);
                 else
-                    fprintf (stderr,"lon: %.5f lat: %.5f\ttendeg[%d][%d] = %d\n",this_lon,this_lat,tenx,teny,tendeg[tenx][teny]);
+                    fprintf (stderr,"lon: %.5f lat: %.5f\ttendeg[%d][%d] = %d\n",this_lon,this_lat,tenx,teny,tendeg[tenx][teny])
+#endif
 				nten++;
 			}
 			/* Count the number of non-NaN observations */
@@ -455,8 +366,12 @@ int main (int argc, char **argv)
 		strncpy (MGD77_Header_Lookup[id].ptr[MGD77_M77_SET],value,MGD77_Header_Lookup[id].length);
 		sprintf (value,"11111");
 		if (counter[b_col]) value[0] = '5';
+		else if (counter[twt_col]) value[0] = '5';
 		if (counter[m_col]) value[1] = '5';
+		else if (counter[mt1_col]) value[1] = '5';
+		else if (counter[mt2_col]) value[1] = '5';
 		if (counter[f_col]) value[2] = '5';
+		else if (counter[g_col]) value[2] = '5';
 		strcpy(params,value);
 		sprintf (name,"Parameters_Surveyed_Code");
 		id = MGD77_Get_Header_Item (&M, name);
@@ -507,31 +422,6 @@ int main (int argc, char **argv)
 			}
 		}
 
-		if (first && quick_summary) {	/* Output all column headers */
-			for (i = 0; i < M.n_out_columns; i++) {
-				if (i == id_col || i == t_col || i == x_col || i == y_col) continue;
-				sprintf (buffer,"%s%s", gmtdefs.field_delimiter, D->H.info[M.order[i].set].col[M.order[i].item].abbrev);
-				GMT_fputs (buffer, GMT_stdout);
-			}
-			GMT_fputs ("\n", GMT_stdout);
-		}
-
-		if (col_summary) {	/* Just list names and info for any extra columns */
-			for (i = 0, first = TRUE; i < M.n_out_columns; i++) {
-				if (i == id_col || i == t_col || i == x_col || i == y_col) continue;
-				if (!first) GMT_fputs (gmtdefs.field_delimiter, GMT_stdout);
-				if (((col_listing & 1) && M.order[i].set == 0) || ((col_listing & 2) && M.order[i].set == 1)) {
-					GMT_fputs (D->H.info[M.order[i].set].col[M.order[i].item].abbrev, GMT_stdout);
-					first = FALSE;
-				}
-			}
-			if (first) GMT_fputs ("No columns matching selection found!", GMT_stdout);
-			GMT_fputs ("\n", GMT_stdout);
-			MGD77_Close_File (&M);
-			MGD77_Free (D);
-			continue;
-		}
-
 		if (dump_formatted_header) {	/* Dump of header items, one per line */
 			MGD77_Dump_Header_Params (&M, D->H.mgd77[use]);
 			MGD77_Close_File (&M);
@@ -549,59 +439,21 @@ int main (int argc, char **argv)
 				GMT_fputs ("----------------------------------------", GMT_stdout);
 				sprintf (buffer, "----------------------------------------\n");	GMT_fputs (buffer, GMT_stdout);
 			}
-			if (M.format == MGD77_FORMAT_CDF) {
-				sprintf (buffer, "%s\n", D->H.history);
-				GMT_fputs (buffer, GMT_stdout);
-				for (i = 0; i < M.n_out_columns; i++) {
-					if (M.order[i].set == MGD77_CDF_SET) {
-						sprintf (buffer, "> %s%s%s%s%s%s%s", D->H.info[MGD77_CDF_SET].col[M.order[i].item].abbrev, gmtdefs.field_delimiter,
-							D->H.info[MGD77_CDF_SET].col[M.order[i].item].name, gmtdefs.field_delimiter,
-							D->H.info[MGD77_CDF_SET].col[M.order[i].item].units, gmtdefs.field_delimiter,
-							D->H.info[MGD77_CDF_SET].col[M.order[i].item].comment);
-						GMT_fputs ("\n", GMT_stdout);
-					}
-				}
-			}
 			if (infile == NULL) GMT_fputs ("\n", GMT_stdout);
 		}
 
-		if (quick_summary) {
-			sprintf (buffer,"%8s%s%8s%s", M.NGDC_id, gmtdefs.field_delimiter, D->H.mgd77[use]->Survey_Identifier, gmtdefs.field_delimiter);
-			GMT_fputs (buffer, GMT_stdout);
-			GMT_ascii_output_one (GMT_stdout, xmin, 0);	GMT_fputs (gmtdefs.field_delimiter, GMT_stdout);
-			GMT_ascii_output_one (GMT_stdout, xmax, 0);	GMT_fputs (gmtdefs.field_delimiter, GMT_stdout);
-			GMT_ascii_output_one (GMT_stdout, ymin, 1);	GMT_fputs (gmtdefs.field_delimiter, GMT_stdout);
-			GMT_ascii_output_one (GMT_stdout, ymax, 1);	GMT_fputs (gmtdefs.field_delimiter, GMT_stdout);
-			GMT_ascii_output_one (GMT_stdout, tmin, 2);	GMT_fputs (gmtdefs.field_delimiter, GMT_stdout);
-			GMT_ascii_output_one (GMT_stdout, tmax, 2);	GMT_fputs (gmtdefs.field_delimiter, GMT_stdout);
-			sprintf (buffer, "%ld%s%ld", (GMT_LONG)irint (this_dist), gmtdefs.field_delimiter, D->H.n_records);
-			GMT_fputs (buffer, GMT_stdout);
-			for (i = 1; i < M.n_out_columns; i++) {
-				if (i == id_col || i == t_col || i == x_col || i == y_col) continue;
-				if (((col_listing & 1) && M.order[i].set == 0) || ((col_listing & 2) && M.order[i].set == 1)) {
-					sprintf (buffer,"%s%ld",	gmtdefs.field_delimiter, counter[i]);
-					GMT_fputs (buffer, GMT_stdout);
-				}
+		if (dump_m77t_header) {	/* Write entire M77T header */
+			if (infile == NULL) {
+				GMT_fputs ("-------------------------------", GMT_stdout);
+				sprintf (buffer, " Cruise: %8s ", M.NGDC_id);	GMT_fputs (buffer, GMT_stdout);
+				GMT_fputs ("-------------------------------\n", GMT_stdout);
 			}
-			GMT_fputs ("\n", GMT_stdout);
-		}
-		if (dump_hist_header) {	/* Dump of MGD77+ history */
-			sprintf (buffer, "%s: %s", list[argno], D->H.history);
-			GMT_fputs (buffer, GMT_stdout);
-			MGD77_Close_File (&M);
-			continue;
-		}
-		if (dump_e77_header) {	/* Dump of e77 header status */
-			if (D->H.E77 && strlen(D->H.E77) > 0) {
-				sprintf (buffer, "%s: %s\n", list[argno], D->H.E77);
-				GMT_fputs (buffer, GMT_stdout);
+			MGD77_Write_Header_Record_m77t ("", &Out, &D->H);
+			if (infile == NULL) {
+				GMT_fputs ("----------------------------------------", GMT_stdout);
+				sprintf (buffer, "----------------------------------------\n");	GMT_fputs (buffer, GMT_stdout);
 			}
-			else {
-				sprintf (buffer, "%s: E77 not applied\n", list[argno]);
-				GMT_fputs (buffer, GMT_stdout);
-			}
-			MGD77_Close_File (&M);
-			continue;
+			if (infile == NULL) GMT_fputs ("\n", GMT_stdout);
 		}
 
 		MGD77_Free (D);
