@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: mgd77list.c 10350 2016-06-22 06:20:28Z pwessel $
+ *	$Id: mgd77list.c 10374 2017-01-16 20:53:19Z pwessel $
  *
- *    Copyright (c) 2004-2016 by P. Wessel
+ *    Copyright (c) 2004-2017 by P. Wessel
  *    See README file for copying and redistribution conditions.
  *--------------------------------------------------------------------*/
 /*
@@ -47,6 +47,32 @@
 #define ADJ_GR	2
 #define ADJ_MG	3
 
+/* Carter adjustment options */
+#define CT_U_MINUS_DEPTH				1
+#define CT_U_MINUS_CARTER				2
+#define CT_UCORR_MINUS_CARTER_TU		4
+#define CT_UCORR_CARTER_TU_MINUS_DEPTH	8
+
+/* FAA adjustment options */
+#define GR_FAA_STORED					1
+#define GR_OBS_MINUS_NGRAV				2
+#define GR_OBS_PLUS_EOT_MINUS_NGRAV		4
+#define GR_OBS_PLUS_CEOT_MINUS_NGRAV	8
+
+/* Depth adjustment options */
+#define DP_DEPTH_STORED				1
+#define DP_TWT_X_V					2
+#define DP_TWT_X_V_MINUS_CARTER		4
+
+/* Mag adjustment options */
+#define MG_MAG_STORED			1
+#define MG_MTF1_MINUS_IGRF		2
+#define MG_MTF2_MINUS_IGRF		4
+#ifdef USE_CM4
+#define MG_MTF1_MINUS_CM4		8
+#define MG_MTF2_MINUS_CM4		16
+#endif
+
 int main (int argc, char **argv)
 {
 	int i, c, id, k, kx, pos, argno, code, n_cruises = 0, n_paths, use, n_items = 0, t_pos = MGD77_NOT_SET;
@@ -526,7 +552,8 @@ int main (int argc, char **argv)
 		fprintf (stderr, "\t  separated -+|-<col> terms.  This compares specific bitflags for each listed column\n");
 		fprintf (stderr, "\t  + means bit must be 1, - means it must be 0.  All bit tests given must be passed.\n");
 		fprintf (stderr, "\t  By default, MGD77+ files with error bit flags will use the flags to suppress bad data.\n");
-		fprintf (stderr, "\t  Turn this behavior off by append : with no arguments.\n");
+		fprintf (stderr, "\t  Turn this behavior off by append : with no arguments.  For controlling systematic\n");
+		fprintf (stderr, "\t  corrections encoded in MGD77+ files, see -T.\n");
 		fprintf (stderr, "\tOPTIONS:\n\n");
 		fprintf (stderr, "\t-A Adjust some data values before output. Append c|d|f|m|t to select field:\n");
 		fprintf (stderr, "\t   c<code>[,<v>] Adjust field carter. <v>, the sound velocity in water, is taken from\n");
@@ -570,15 +597,16 @@ int main (int argc, char **argv)
 		fprintf (stderr, "\t   g Great circle [Default]\n");
 		fprintf (stderr, "\t   e Ellipsoidal (geodesic) using current ellipsoid\n");
 		fprintf (stderr, "\t-Da<date> lists from date (given as yyyy-mm-ddT[hh:mm:ss]) [Start of cruise]\n");
-		fprintf (stderr, "\t  b<date> lists up to date (given as yyyy-mm-ddT[hh:mm:ss]) [End of cruise]\n");
-		fprintf (stderr, "\t  If A|B is used instead or a|b then records with no time are excluded from output\n");
+		fprintf (stderr, "\t   b<date> lists up to date (given as yyyy-mm-ddT[hh:mm:ss]) [End of cruise]\n");
+		fprintf (stderr, "\t   If A|B is used instead or a|b then records with no time are excluded from output\n");
 		fprintf (stderr, "\t-E Only records that exactly matches the requested geophysical information in -F will be used.\n");
 		fprintf (stderr, "\t   [Default will output all record that matches at least one column]\n");
 		fprintf (stderr, "\t-Ga<rec> lists from given record [Start of cruise]\n");
-		fprintf (stderr, "\t  b<rec> lists up to given record [End of cruise]\n");
+		fprintf (stderr, "\t   b<rec> lists up to given record [End of cruise]\n");
 		fprintf (stderr, "\t-H Write one header record with column names\n");
 		fprintf (stderr, "\t-I Ignore certain data file formats from consideration. Append combination of act to ignore\n");
 		fprintf (stderr, "\t   (a) MGD77 ASCII, (c) MGD77+ netCDF, (m) MGD77T ASCII, or (t) plain table files. [Default ignores none]\n");
+		fprintf (stderr, "	   Search sequence for extensions is MGD77+, MGD77T, MGD77, plain table.\n");
 		fprintf (stderr, "\t-L Subtract systematic corrections from the data. If no correction file is given,\n");
 		fprintf (stderr, "\t   the default file mgd77_corrections.txt in $MGD77_HOME is assumed.\n");
 		fprintf (stderr, "\t-N Append (d)istances or (s)peed, and your choice for unit. Choose among:\n");
@@ -596,7 +624,7 @@ int main (int argc, char **argv)
 		fprintf (stderr, "\t-Sb<dist> lists up to dist (in m; append k, m, or n) [End of the cruise]\n");
 		fprintf (stderr, "\t-T turns OFF the otherwise automatic adjustment of values based on correction terms\n");
 		fprintf (stderr, "\t   stored in the mgd77+ file (option has no effect on plain MGD77 ASCII files).\n");
-		fprintf (stderr, "\t   Append m or e to indicate the MGD77 data set or the extended columns set. [Default is both]\n");
+		fprintf (stderr, "\t   For controlling application of point bit flags, see -F and the : modifier discussion.\n");
 		fprintf (stderr, "\t-V Verbose, report progress\n");
 		fprintf (stderr, "\t-W Sets weight for these data [1]\n");
 		fprintf (stderr, "\t-Z Append - to report bathymetry & msd as negative depths [Default is positive -Z+]\n");
@@ -651,8 +679,8 @@ int main (int argc, char **argv)
 	 */
 	 
 	need_distances = (limit_on_dist || auxlist[MGD77_AUX_SP].requested || auxlist[MGD77_AUX_DS].requested || auxlist[MGD77_AUX_AZ].requested);	/* Distance is requested */
-	need_lonlat = (auxlist[MGD77_AUX_MG].requested || auxlist[MGD77_AUX_GR].requested || auxlist[MGD77_AUX_CT].requested || adj_code[ADJ_MG] > 1 || adj_code[ADJ_DP] & 4 || adj_code[ADJ_CT] >= 2 || adj_code[ADJ_GR] > 1 || fake_times);	/* Need lon, lat to calculate reference fields or Carter correction */
-	need_time = (auxlist[MGD77_AUX_YR].requested || auxlist[MGD77_AUX_MO].requested || auxlist[MGD77_AUX_DY].requested || auxlist[MGD77_AUX_HR].requested || auxlist[MGD77_AUX_MI].requested || auxlist[MGD77_AUX_SC].requested || auxlist[MGD77_AUX_DM].requested || auxlist[MGD77_AUX_HM].requested || auxlist[MGD77_AUX_DA].requested || auxlist[MGD77_AUX_MG].requested || (adj_code[ADJ_MG] > 1));
+	need_lonlat = (auxlist[MGD77_AUX_MG].requested || auxlist[MGD77_AUX_GR].requested || auxlist[MGD77_AUX_CT].requested || adj_code[ADJ_MG] > MG_MAG_STORED || adj_code[ADJ_DP] & DP_TWT_X_V_MINUS_CARTER || adj_code[ADJ_CT] >= CT_U_MINUS_CARTER || adj_code[ADJ_GR] > GR_FAA_STORED || fake_times);	/* Need lon, lat to calculate reference fields or Carter correction */
+	need_time = (auxlist[MGD77_AUX_YR].requested || auxlist[MGD77_AUX_MO].requested || auxlist[MGD77_AUX_DY].requested || auxlist[MGD77_AUX_HR].requested || auxlist[MGD77_AUX_MI].requested || auxlist[MGD77_AUX_SC].requested || auxlist[MGD77_AUX_DM].requested || auxlist[MGD77_AUX_HM].requested || auxlist[MGD77_AUX_DA].requested || auxlist[MGD77_AUX_MG].requested || (adj_code[ADJ_MG] > MG_MAG_STORED));
 #ifdef USE_CM4
 	if (auxlist[MGD77_AUX_CM].requested) need_lonlat = need_time = TRUE;
 #endif
@@ -663,22 +691,22 @@ int main (int argc, char **argv)
 		 if (MGD77_Get_Column ("lon", &M) == MGD77_NOT_SET) strcat (fx_setting, ",lon"), n_sub++;	/* Append lon to requested list */
 	}
 	if ((limit_on_time || need_time || auxlist[MGD77_AUX_SP].requested) && MGD77_Get_Column ("time", &M) == MGD77_NOT_SET) strcat (fx_setting, ",time"), n_sub++;	/* Append time to requested list */
-	need_twt = (auxlist[MGD77_AUX_CT].requested || (adj_code[ADJ_CT] > 0 && adj_code[ADJ_CT] < 3) || (adj_code[ADJ_DP] > 1));
+	need_twt = (auxlist[MGD77_AUX_CT].requested || (adj_code[ADJ_CT] > 0 && adj_code[ADJ_CT] <= CT_U_MINUS_CARTER) || (adj_code[ADJ_DP] > DP_DEPTH_STORED));
 	if (need_twt) {	/* Want to estimate Carter corrections */
 		 if (MGD77_Get_Column ("twt", &M) == MGD77_NOT_SET) strcat (fx_setting, ",twt"), n_sub++;	/* Must append twt to requested list */
 		MGD77_carter_init (&Carter);	/* Initialize Carter machinery */
 	}
-	need_depth = ((adj_code[ADJ_CT] & (1 | 3 | 8)) || (adj_code[ADJ_DP] & 1));
+	need_depth = ((adj_code[ADJ_CT] & (CT_U_MINUS_DEPTH | CT_UCORR_MINUS_CARTER_TU | CT_UCORR_CARTER_TU_MINUS_DEPTH)) || (adj_code[ADJ_DP] & DP_DEPTH_STORED));
 	if (need_depth) {	/* Need depth*/
 		 if (MGD77_Get_Column ("depth", &M) == MGD77_NOT_SET) strcat (fx_setting, ",depth"), n_sub++;	/* Must append depth to requested list */
 	}
-	if (adj_code[ADJ_GR] > 1) {	/* Need gobs */
+	if (adj_code[ADJ_GR] > GR_FAA_STORED) {	/* Need gobs */
 		 if (MGD77_Get_Column ("gobs", &M) == MGD77_NOT_SET) strcat (fx_setting, ",gobs"), n_sub++;	/* Must append gobs to requested list */
 	}
-	if (adj_code[ADJ_GR] == 3) {	/* Need eot */
+	if (adj_code[ADJ_GR] & GR_OBS_PLUS_EOT_MINUS_NGRAV) {	/* Need eot */
 		 if (MGD77_Get_Column ("eot", &M) == MGD77_NOT_SET) strcat (fx_setting, ",eot"), n_sub++;	/* Must append eot to requested list */
 	}
-	if (adj_code[ADJ_MG] > 1) {	/* Need mtf1,2, and msens */
+	if (adj_code[ADJ_MG] > MG_MAG_STORED) {	/* Need mtf1,2, and msens */
 		 if (MGD77_Get_Column ("mtf1", &M) == MGD77_NOT_SET) strcat (fx_setting, ",mtf1"), n_sub++;	/* Must append mtf1 to requested list */
 		 if (MGD77_Get_Column ("mtf2", &M) == MGD77_NOT_SET) strcat (fx_setting, ",mtf2"), n_sub++;	/* Must append mtf2 to requested list */
 		 if (MGD77_Get_Column ("msens", &M) == MGD77_NOT_SET) strcat (fx_setting, ",msens"), n_sub++;	/* Must append msens to requested list */
@@ -690,7 +718,7 @@ int main (int argc, char **argv)
 		strcat (fx_setting, M.Constraint[i].name);	/* Must add to our list */
 		n_sub++;
 	}
-	need_sound = (((adj_code[ADJ_CT] & (1 | 2 | 8)) || adj_code[ADJ_DP] & 2) && sound_speed == 0.0);
+	need_sound = (((adj_code[ADJ_CT] & (CT_U_MINUS_DEPTH | CT_U_MINUS_CARTER | CT_UCORR_CARTER_TU_MINUS_DEPTH)) || adj_code[ADJ_DP] & DP_TWT_X_V) && sound_speed == 0.0);
 	sound_speed *= 0.5;	/* Takes care of the 2 in 2-way travel time */
 	MGD77_Select_Columns (fx_setting, &M, 0);	/* Only deal with col names - leave constraints/exacts unchanged from last call */
 	n_cols_to_process = M.n_out_columns - n_sub;
@@ -870,15 +898,15 @@ int main (int argc, char **argv)
 		z_col = MGD77_Get_Column ("depth",  &M);
 		if (need_twt) twt_col = MGD77_Get_Column ("twt",  &M);
 		if (adj_code[ADJ_GR]) f_col = MGD77_Get_Column ("faa",  &M);
-		if (adj_code[ADJ_GR] > 1) g_col = MGD77_Get_Column ("gobs",  &M);
-		if (adj_code[ADJ_GR] == 3) e_col = MGD77_Get_Column ("eot",  &M);
+		if (adj_code[ADJ_GR] > GR_FAA_STORED) g_col = MGD77_Get_Column ("gobs",  &M);
+		if (adj_code[ADJ_GR] & GR_OBS_PLUS_EOT_MINUS_NGRAV) e_col = MGD77_Get_Column ("eot",  &M);
 		if (adj_code[ADJ_MG]) m_col = MGD77_Get_Column ("mag",  &M);
-		if (adj_code[ADJ_MG] > 1) {	/* Need more magnetics items */
+		if (adj_code[ADJ_MG] > MG_MAG_STORED) {	/* Need more magnetics items */
 			m1_col = MGD77_Get_Column ("mtf1",  &M);
 			m2_col = MGD77_Get_Column ("mtf2",  &M);
 			ms_col = MGD77_Get_Column ("msens",  &M);
 		}
-		if ((auxlist[MGD77_AUX_GR].requested || (adj_code[ADJ_GR] > 1 )) && GF_version == MGD77_NOT_SET) {
+		if ((auxlist[MGD77_AUX_GR].requested || (adj_code[ADJ_GR] > GR_FAA_STORED)) && GF_version == MGD77_NOT_SET) {
 			GF_version = D->H.mgd77[use]->Gravity_Theoretical_Formula_Code - '0';
 			if (GF_version < MGD77_IGF_HEISKANEN || GF_version > MGD77_IGF_1980) {
 				fprintf (stderr, "%s: Invalid Gravity Theoretical Formula Code (%c) - default to %d\n", GMT_program, D->H.mgd77[use]->Gravity_Theoretical_Formula_Code, MGD77_IGF_1980);
@@ -1015,18 +1043,18 @@ int main (int argc, char **argv)
 			if (auxlist[MGD77_AUX_CT].requested) {	/* Carter is one of the output columns */
 				if (adj_code[ADJ_CT]) {	/* We have requested some adjustment to the carter value */
 					aux_dvalue[MGD77_AUX_CT] = GMT_d_NaN;
-					if (adj_code[ADJ_CT] & 1)	/* Try uncorr. depth - obs. depth */
+					if (adj_code[ADJ_CT] & CT_U_MINUS_DEPTH)	/* Try uncorr. depth - obs. depth */
 						aux_dvalue[MGD77_AUX_CT] = dvalue[twt_col][rec] * sound_speed - dvalue[z_col][rec];	/* Factor of 2 dealt with earlier */
-					if (adj_code[ADJ_CT] & 2 && GMT_is_dnan (aux_dvalue[MGD77_AUX_CT])) {	/* Try uncorr. depth - Carter depth */
+					if ((adj_code[ADJ_CT] & CT_U_MINUS_CARTER) && GMT_is_dnan (aux_dvalue[MGD77_AUX_CT])) {	/* Try uncorr. depth - Carter depth */
 						MGD77_carter_depth_from_xytwt (dvalue[x_col][rec], dvalue[y_col][rec], 1000.0 * dvalue[twt_col][rec], &Carter, &z);
 						aux_dvalue[MGD77_AUX_CT] = dvalue[twt_col][rec] * i_sound_speed - z;
 					}
-					if (adj_code[ADJ_CT] & 4 && GMT_is_dnan (aux_dvalue[MGD77_AUX_CT])) {	/* Try uncorr. depth - inferred Carter depth */
+					if ((adj_code[ADJ_CT] & CT_UCORR_MINUS_CARTER_TU) && GMT_is_dnan (aux_dvalue[MGD77_AUX_CT])) {	/* Try uncorr. depth - inferred Carter depth */
 						twt = dvalue[z_col][rec] * i_sound_speed;	/* Factor of 2 dealt with earlier */
 						MGD77_carter_depth_from_xytwt (dvalue[x_col][rec], dvalue[y_col][rec], twt, &Carter, &z);
 						aux_dvalue[MGD77_AUX_CT] = dvalue[z_col][rec] - z;
 					}
-					if (adj_code[ADJ_CT] & 8 && GMT_is_dnan (aux_dvalue[MGD77_AUX_CT])) {	/* Try inferred uncorr. depth - obs. depth */
+					if ((adj_code[ADJ_CT] & CT_UCORR_CARTER_TU_MINUS_DEPTH) && GMT_is_dnan (aux_dvalue[MGD77_AUX_CT])) {	/* Try inferred uncorr. depth - obs. depth */
 						MGD77_carter_twt_from_xydepth (dvalue[x_col][rec], dvalue[y_col][rec], dvalue[z_col][rec], &Carter, &twt);
 						z = twt * sound_speed;
 						aux_dvalue[MGD77_AUX_CT] = z - dvalue[z_col][rec];
@@ -1041,11 +1069,11 @@ int main (int argc, char **argv)
 
 			if (z_col != MGD77_NOT_SET && adj_code[ADJ_DP]) {	/* We have requested some adjustment to the depth value */
 				z = GMT_d_NaN;
-				if (adj_code[ADJ_DP] & 1)	/* Try obs. depth */
+				if (adj_code[ADJ_DP] & DP_DEPTH_STORED)	/* Try obs. depth */
 					z = dvalue[z_col][rec];
-				if (adj_code[ADJ_DP] & 2 && GMT_is_dnan (z))	/* Try uncorr. depth */
+				if (adj_code[ADJ_DP] & DP_TWT_X_V && GMT_is_dnan (z))	/* Try uncorr. depth */
 					z = dvalue[twt_col][rec] * i_sound_speed;
-				if (adj_code[ADJ_DP] & 4 && GMT_is_dnan (z)) {	/* Try Carter depth */
+				if (adj_code[ADJ_DP] & DP_TWT_X_V_MINUS_CARTER && GMT_is_dnan (z)) {	/* Try Carter depth */
 					twt = dvalue[twt_col][rec];
 					if (!GMT_is_dnan (twt)) {	/* OK, valid twt */
 						if (has_prev_twt) {	/* OK, may look at change in twt */
@@ -1067,20 +1095,20 @@ int main (int argc, char **argv)
 			
 			if (f_col != MGD77_NOT_SET && adj_code[ADJ_GR]) {	/* We have requested some adjustment to the faa value */
 				g = GMT_d_NaN;
-				if (adj_code[ADJ_GR] == 1)	/* Try faa */
+				if (adj_code[ADJ_GR] & GR_FAA_STORED)	/* Try faa */
 					g = dvalue[f_col][rec];
-				if (adj_code[ADJ_GR] == 2 && GMT_is_dnan (g))	/* Try gobs - ngrav */
+				if ((adj_code[ADJ_GR] & GR_OBS_MINUS_NGRAV) && GMT_is_dnan (g))	/* Try gobs - ngrav */
 					g = dvalue[g_col][rec] - MGD77_Theoretical_Gravity (dvalue[x_col][rec], dvalue[y_col][rec], GF_version);
-				if (adj_code[ADJ_GR] == 3 && GMT_is_dnan (g))	/* Try gobs + eot - ngrav */
+				if ((adj_code[ADJ_GR] & GR_OBS_PLUS_EOT_MINUS_NGRAV) && GMT_is_dnan (g))	/* Try gobs + eot - ngrav */
 					g = dvalue[g_col][rec] + dvalue[e_col][rec] - MGD77_Theoretical_Gravity (dvalue[x_col][rec], dvalue[y_col][rec], GF_version);
 				if (adj_force || !GMT_is_dnan(dvalue[f_col][rec])) dvalue[f_col][rec] = g;
 			}
 			
 			if (m_col != MGD77_NOT_SET && adj_code[ADJ_MG]) {	/* We have requested some adjustment to the mag value */
 				m = GMT_d_NaN;
-				if (adj_code[ADJ_MG] & 1)	/* Try mag */
+				if (adj_code[ADJ_MG] & MG_MAG_STORED)	/* Try mag */
 					m = dvalue[m_col][rec];
-				if (adj_code[ADJ_MG] & 2 && GMT_is_dnan (m)) {	/* Try mtf 1st - igrf */
+				if ((adj_code[ADJ_MG] & MG_MTF1_MINUS_IGRF) && GMT_is_dnan (m)) {	/* Try mtf 1st - igrf */
 					if (need_date) {	/* Did not get computed already */
 						date = MGD77_time_to_fyear (&M, dvalue[t_col][rec]);
 						need_date = FALSE;
@@ -1089,7 +1117,7 @@ int main (int argc, char **argv)
 					k = (i == 2) ? m2_col : m1_col;
 					m = MGD77_Recalc_Mag_Anomaly_IGRF (&M, date, dvalue[x_col][rec], dvalue[y_col][rec], dvalue[k][rec], FALSE);
 				}
-				if (adj_code[ADJ_MG] & 4 && GMT_is_dnan (m)) {	/* Try mtf 2nd - igrf */
+				if ((adj_code[ADJ_MG] & MG_MTF2_MINUS_IGRF) && GMT_is_dnan (m)) {	/* Try mtf 2nd - igrf */
 					if (need_date) {	/* Did not get computed already */
 						date = MGD77_time_to_fyear (&M, dvalue[t_col][rec]);
 						need_date = FALSE;
@@ -1099,7 +1127,7 @@ int main (int argc, char **argv)
 					m = MGD77_Recalc_Mag_Anomaly_IGRF (&M, date, dvalue[x_col][rec], dvalue[y_col][rec], dvalue[k][rec], FALSE);
 				}
 #ifdef USE_CM4
-				if (adj_code[ADJ_MG] & 8 && GMT_is_dnan (m)) {	/* Try mtf 1st - cm4 */
+				if ((adj_code[ADJ_MG] & MG_MTF1_MINUS_CM4) && GMT_is_dnan (m)) {	/* Try mtf 1st - cm4 */
 					if (need_date) {	/* Did not get computed already */
 						date = MGD77_time_to_fyear (&M, dvalue[t_col][rec]);
 						need_date = FALSE;
@@ -1108,7 +1136,7 @@ int main (int argc, char **argv)
 					k = (i == 2) ? m2_col : m1_col;
 					m = MGD77_Recalc_Mag_Anomaly_CM4 (&M, date, dvalue[x_col][rec], dvalue[y_col][rec], dvalue[k][rec], FALSE, &CM4);
 				}
-				if (adj_code[ADJ_MG] & 16 && GMT_is_dnan (m)) {	/* Try mtf 2nd - cm4 */
+				if ((adj_code[ADJ_MG] & MG_MTF2_MINUS_CM4) && GMT_is_dnan (m)) {	/* Try mtf 2nd - cm4 */
 					if (need_date) {	/* Did not get computed already */
 						date = MGD77_time_to_fyear (&M, dvalue[t_col][rec]);
 						need_date = FALSE;
