@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: mgd77track.c 10344 2016-03-07 01:35:42Z pwessel $
+ *	$Id: mgd77track.c 10384 2017-06-14 19:57:45Z pwessel $
  *
- *    Copyright (c) 2004-2016 by P. Wessel
+ *    Copyright (c) 2004-2017 by P. Wessel
  *    See README file for copying and redistribution conditions.
  *--------------------------------------------------------------------*/
 /*
@@ -322,6 +322,7 @@ int main (int argc, char **argv)
 		fprintf(stderr,"	-G Consider point separations exceeding d<gap> (km) or t<gap> (minutes) to indicate a gap (do not draw) [0]\n");
 		fprintf(stderr,"	-I Ignore certain data file formats from consideration. Append combination of act to ignore\n");
 		fprintf (stderr, "	   (a) MGD77 ASCII, (c) MGD77+ netCDF, (m) MGD77T ASCII, or (t) plain table files. [Default ignores none]\n");
+		fprintf(stderr,"	   Search sequence for extensions is MGD77+, MGD77T, MGD77, plain table.\n");
 		GMT_explain_option ('K');
 		fprintf (stderr, "	-L puts time/distance log marks on the track. E.g. a500ka24ht6h means (a)nnotate\n");
 		fprintf (stderr, "	   every 500 km (k) and 24 h(ours), with (t)ickmarks every 500 km and 6 (h)ours\n");
@@ -500,9 +501,9 @@ int main (int argc, char **argv)
 					angle += 90.0;
 				else
 					angle -= 90.0;
-				if (annot_tick[ANNOT] & 1) {	/* Time mark */
-					GMT_gcal_from_dt (annot_time[ANNOT], &calendar);			/* Convert t to a complete calendar structure */
-					GMT_format_calendar (date, clock, &GMT_plot_calclock.date, &GMT_plot_calclock.clock, FALSE, 1, annot_time[ANNOT]);
+				if (annot_tick[ANNOT] & 1) {	/* Time mark: Subtrack increment since we already applied increment above */
+					GMT_gcal_from_dt (annot_time[ANNOT]-info[ANNOT].annot_int_time, &calendar);			/* Convert t to a complete calendar structure */
+					GMT_format_calendar (date, clock, &GMT_plot_calclock.date, &GMT_plot_calclock.clock, FALSE, 1, annot_time[ANNOT]-info[ANNOT].annot_int_time);
 					this_julian = calendar.day_y;
 					if (this_julian != last_julian) {
 						mrk = MGD77TRACK_MARK_NEWDAY;
