@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: gmttrack.c 10344 2016-03-07 01:35:42Z pwessel $
+ *	$Id: gmttrack.c 10384 2017-06-14 19:57:45Z pwessel $
  *
- *    Copyright (c) 1991-2016 by P. Wessel and W. H. F. Smith
+ *    Copyright (c) 1991-2017 by P. Wessel and W. H. F. Smith
  *    See README file for copying and redistribution conditions.
  *--------------------------------------------------------------------*/
 /*
@@ -343,7 +343,7 @@ int main (int argc, char **argv)
 					angle += 90.0;
 				else
 					angle -= 90.0;
-				if (annot_tick & 1) {	/* Time mark */
+				if (annot_tick & 1) {	/* Time mark: Must subtack the annot_int_time since we already increment above */
 					this_julian = gmtmgg_date (annot_time - info.annot_int_time,&year,&month,&day,&hour,&minute,&second,gmt);
 					ps_command ("S");
 					if (this_julian != last_julian) {
